==> bfilter-0.10.1.tar.gz: bfilter-0.10.1/main/DeflateCompressor.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef DEFLATECOMPRESSOR_H_
#define DEFLATECOMPRESSOR_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "types.h"
#include "AbstractCompressor.h"
#include "NonCopyable.h"
#include "SplittableBuffer.h"
#include <zlib.h>
#include <stddef.h>
#include <limits>

class DataChunk;

class DeflateCompressor : public AbstractCompressor, private NonCopyable
{
public:
	enum Flavor { ZLIB, RAW };

	DeflateCompressor(Flavor flavor);
	
	virtual ~DeflateCompressor();
	
	virtual void reset();
	
	virtual bool isError() const;
	
	virtual void consume(SplittableBuffer& data, bool eof);
	
	virtual size_t retrieveOutput(SplittableBuffer& buf,
		size_t limit = std::numeric_limits<size_t>::max());
private:
	enum { MAX_OUTBUF_SIZE = 8192 };
	enum { MAX_OUTPUT_LATENCY = 8192 };
	enum State { ST_COMPRESSING, ST_FINISHED, ST_ERROR };
	
	struct OperationContext;
	
	void initStream();
	
	void compress(
		uint8_t const*& begin, uint8_t const* end,
		SplittableBuffer& out, OperationContext& ctx);
	
	Flavor m_flavor;
	State m_state;
	SplittableBuffer m_bufferedInput;
	size_t m_outputLatency; /* number of bytes consumed by deflate()
	without producing any output */
	int m_flushParam;
	bool m_isEOF;
	z_stream m_strm;
};

#endif

==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/DeflateCompressor.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2006  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef DEFLATECOMPRESSOR_H_
#define DEFLATECOMPRESSOR_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "types.h"
#include "AbstractCompressor.h"
#include "NonCopyable.h"
#include "SplittableBuffer.h"
#include <zlib.h>
#include <stddef.h>
#include <limits>

class DataChunk;

class DeflateCompressor : public AbstractCompressor
{
	DECLARE_NON_COPYABLE(DeflateCompressor)
public:
	enum Flavor { ZLIB, RAW };

	DeflateCompressor(Flavor flavor);
	
	virtual ~DeflateCompressor();
	
	virtual void reset();
	
	virtual bool isError() const;
	
	virtual void consume(SplittableBuffer& data, bool eof);
	
	virtual size_t retrieveOutput(SplittableBuffer& buf,
		size_t limit = std::numeric_limits<size_t>::max());
private:
	enum { MAX_OUTBUF_SIZE = 8192 };
	enum { MAX_OUTPUT_LATENCY = 8192 };
	enum State { ST_COMPRESSING, ST_FINISHED, ST_ERROR };
	
	struct OperationContext;
	
	void initStream();
	
	void compress(
		uint8_t const*& begin, uint8_t const* end,
		SplittableBuffer& out, OperationContext& ctx);
	
	Flavor m_flavor;
	State m_state;
	SplittableBuffer m_bufferedInput;
	size_t m_outputLatency; /* number of bytes consumed by deflate()
	without producing any output */
	int m_flushParam;
	bool m_isEOF;
	z_stream m_strm;
};

#endif
